svn commit: r292458 - user/alc/PQ_LAUNDRY/sys/vm

Mark Johnston markj at FreeBSD.org
Sat Dec 19 01:37:21 UTC 2015


Author: markj
Date: Sat Dec 19 01:37:20 2015
New Revision: 292458
URL: https://svnweb.freebsd.org/changeset/base/292458

Log:
  Forcibly swapped-in pages should go in the laundry.
  
  Discussed with:	alc

Modified:
  user/alc/PQ_LAUNDRY/sys/vm/swap_pager.c

Modified: user/alc/PQ_LAUNDRY/sys/vm/swap_pager.c
==============================================================================
--- user/alc/PQ_LAUNDRY/sys/vm/swap_pager.c	Sat Dec 19 01:24:07 2015	(r292457)
+++ user/alc/PQ_LAUNDRY/sys/vm/swap_pager.c	Sat Dec 19 01:37:20 2015	(r292458)
@@ -1609,7 +1609,7 @@ swap_pager_isswapped(vm_object_t object,
  *
  *	This routine dissociates the page at the given index within a
  *	swap block from its backing store, paging it in if necessary.
  *	If the page is paged in, it is placed in the inactive queue,
  *	since it had its backing store ripped out from under it.
  *	We also attempt to swap in all other pages in the swap block,
  *	we only guarantee that the one at the specified index is
@@ -1641,7 +1641,7 @@ swp_pager_force_pagein(vm_object_t objec
 	vm_object_pip_wakeup(object);
 	vm_page_dirty(m);
 	vm_page_lock(m);
-	vm_page_deactivate(m);
+	vm_page_laundry(m);
 	vm_page_unlock(m);
 	vm_page_xunbusy(m);
 	vm_pager_page_unswapped(m);
@@ -1609,7 +1609,7 @@ swap_pager_isswapped(vm_object_t object,
  *	This routine dissociates the page at the given index within a
  *	swap block from its backing store, paging it in if necessary.
- *	If the page is paged in, it is placed in the inactive queue,
+ *	If the page is paged in, it is placed in the laundry queue,
  *	since it had its backing store ripped out from under it.
  *	We also attempt to swap in all other pages in the swap block,


More information about the svn-src-user mailing list